@@ -67,16 +67,29 @@ class VoxelGridTest(g.unittest.TestCase):
             g.log.warning("no skimage, skipping marching cubes test")
             return
 
+        march = g.trimesh.voxel.ops.matrix_to_marching_cubes
+
         # make sure offset is correct
         matrix = g.np.ones((3, 3, 3), dtype=bool)
-        mesh = g.trimesh.voxel.ops.matrix_to_marching_cubes(matrix=matrix)
+        mesh = march(matrix=matrix)
         assert mesh.is_watertight
 
-        mesh = g.trimesh.voxel.ops.matrix_to_marching_cubes(matrix=matrix).apply_scale(
-            3.0
-        )
+        mesh = march(matrix=matrix).apply_scale(3.0)
         assert mesh.is_watertight
 
+        # try an array full of a small number
+        matrix = g.np.full((3, 3, 3), 0.01, dtype=g.np.float64)
+        # set some to zero
+        matrix[:2, :2, :2] = 0.0
+
+        a = march(matrix)
+        assert a.is_watertight
+
+        # but above the threshold it should be not empty
+        b = march(matrix, threshold=-0.001)
+        assert b.is_watertight
+        assert b.volume > a.volume
+
     def test_marching_points(self):
         """
         Try marching cubes on points
@@ -163,7 +176,7 @@ class VoxelGridTest(g.unittest.TestCase):
         voxel = g.trimesh.voxel
 
         pitch = 0.1
-        origin = (0, 0, 1)
+        origin = [0, 0, 1]
 
         matrix = g.np.eye(9, dtype=bool).reshape((-1, 3, 3))
         centers = g.trimesh.voxel.ops.matrix_to_points(
