@@ -5,7 +5,6 @@ from typing import (
     IO,
     Any,
     BinaryIO,
-    Mapping,
     Optional,
     TextIO,
     Union,
@@ -21,9 +20,20 @@ if version_info >= (3, 9):
     List = list
     Tuple = tuple
     Dict = dict
-    from collections.abc import Iterable, Sequence
+    Set = set
+    from collections.abc import Callable, Hashable, Iterable, Mapping, Sequence
 else:
-    from typing import Dict, Iterable, List, Sequence, Tuple
+    from typing import (
+        Callable,
+        Dict,
+        Hashable,
+        Iterable,
+        List,
+        Mapping,
+        Sequence,
+        Set,
+        Tuple,
+    )
 
 # most loader routes take `file_obj` which can either be
 # a file-like object or a file path, or sometimes a dict
@@ -38,26 +48,35 @@ Loadable = Union[str, Path, Stream, Dict, None]
 # these wrappers union numpy integers and python integers
 Integer = Union[int, integer, unsignedinteger]
 
-# Many arguments take "any valid number."
-Number = Union[float, floating, Integer]
+# Numbers which can only be floats and will not accept integers
+# > isinstance(np.ones(1, dtype=np.float32)[0], floating) # True
+# > isinstance(np.ones(1, dtype=np.float32)[0], float) # False
+Floating = Union[float, floating]
+
+# Many arguments take "any valid number" and don't care if it
+# is an integer or a floating point input.
+Number = Union[Floating, Integer]
 
 __all__ = [
     "IO",
     "Any",
     "ArrayLike",
     "BinaryIO",
+    "Callable",
     "Dict",
+    "Hashable",
     "Integer",
     "Iterable",
     "List",
     "Loadable",
+    "Mapping",
     "NDArray",
     "Number",
     "Optional",
     "Sequence",
+    "Set",
     "Stream",
     "Tuple",
     "float64",
     "int64",
-    "Mapping",
 ]
